"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


__func_alias__ = {"set_": "set"}


async def set_(
    hub,
    ctx,
    auto_scaling_group_name: str,
    desired_capacity: int,
    honor_cooldown: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets the size of the specified Auto Scaling group. If a scale-in activity occurs as a result of a new DesiredCapacity value that is lower than the current size of the group, the Auto Scaling group uses its termination policy to determine which instances to terminate.  For more information, see Manual scaling in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        desired_capacity(int): The desired capacity is the initial capacity of the Auto Scaling group after this operation completes and the capacity it attempts to maintain.
        honor_cooldown(bool, optional): Indicates whether Amazon EC2 Auto Scaling waits for the cooldown period to complete before initiating a scaling activity to set your Auto Scaling group to its new capacity. By default, Amazon EC2 Auto Scaling does not honor the cooldown period during manual scaling activities. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.desired_capacity.set(
                ctx, auto_scaling_group_name=value, desired_capacity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.desired_capacity.set auto_scaling_group_name=value, desired_capacity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="set_desired_capacity",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "DesiredCapacity": desired_capacity,
            "HonorCooldown": honor_cooldown,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, submitted_since: str = None, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all of the operations that return an operation ID and that have ever been performed on domains that were registered by the current account.

    Args:
        submitted_since(str, optional): An optional parameter that lets you get information about all the operations that you submitted after a specified date and time. Specify the date and time in Unix time format and Coordinated Universal time (UTC). Defaults to None.
        marker(str, optional): For an initial request for a list of operations, omit this element. If the number of operations that are not yet complete is greater than the value that you specified for MaxItems, you can use Marker to return additional operations. Get the value of NextPageMarker from the previous response, and submit another request that includes the value of NextPageMarker in the Marker element. Defaults to None.
        max_items(int, optional): Number of domains to be returned. Default: 20. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.operation.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.operation.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="list_operations",
        op_kwargs={
            "SubmittedSince": submitted_since,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a job.

    Args:
        arn(str): The job's ARN.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.job.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.job.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="devicefarm", operation="get_job", op_kwargs={"arn": arn}
    )


async def stop(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Initiates a stop request for the current job. AWS Device Farm immediately stops the job on the device where tests have not started. You are not billed for this device. On the device where tests have started, setup suite and teardown suite tests run to completion on the device. You are billed for setup, teardown, and any tests that were in progress or already completed.

    Args:
        arn(str): Represents the Amazon Resource Name (ARN) of the Device Farm job to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.job.stop(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.job.stop arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="devicefarm", operation="stop_job", op_kwargs={"arn": arn}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, resource_specification: Dict, file_format: str, file_password: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a zip archive containing the contents of a bot or a bot locale. The archive contains a directory structure that contains JSON files that define the bot. You can create an archive that contains the complete definition of a bot, or you can specify that the archive contain only the definition of a single bot locale. For more information about exporting bots, and about the structure of the export archive, see  Importing and exporting bots

    Args:
        resource_specification(Dict): Specifies the type of resource to export, either a bot or a bot locale. You can only specify one type of resource to export.
        file_format(str): The file format of the bot or bot locale definition files.
        file_password(str, optional): An password to use to encrypt the exported archive. Using a password is optional, but you should encrypt the archive to protect the data in transit between Amazon Lex and your local computer. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.export.create(
                ctx, resource_specification=value, file_format=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.export.create resource_specification=value, file_format=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="create_export",
        op_kwargs={
            "resourceSpecification": resource_specification,
            "fileFormat": file_format,
            "filePassword": file_password,
        },
    )


async def delete(hub, ctx, export_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a previous export and the associated files stored in an S3 bucket.

    Args:
        export_id(str): The unique identifier of the export to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.export.delete(ctx, export_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.export.delete export_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_export",
        op_kwargs={"exportId": export_id},
    )


async def describe(hub, ctx, export_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specific export.

    Args:
        export_id(str): The unique identifier of the export to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.export.describe(ctx, export_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.export.describe export_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="describe_export",
        op_kwargs={"exportId": export_id},
    )


async def list_all(
    hub,
    ctx,
    bot_id: str = None,
    bot_version: str = None,
    sort_by: Dict = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the exports for a bot or bot locale. Exports are kept in the list for 7 days.

    Args:
        bot_id(str, optional): The unique identifier that Amazon Lex assigned to the bot. Defaults to None.
        bot_version(str, optional): The version of the bot to list exports for. . Defaults to None.
        sort_by(Dict, optional): Determines the field that the list of exports is sorted by. You can sort by the LastUpdatedDateTime field in ascending or descending order. Defaults to None.
        filters(List, optional): Provides the specification of a filter used to limit the exports in the response to only those that match the filter specification. You can only specify one filter and one string to filter on. Defaults to None.
        max_results(int, optional): The maximum number of exports to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned. Defaults to None.
        next_token(str, optional): If the response from the ListExports operation contans more results that specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.export.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.export.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="list_exports",
        op_kwargs={
            "botId": bot_id,
            "botVersion": bot_version,
            "sortBy": sort_by,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(hub, ctx, export_id: str, file_password: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the password used to protect an export zip archive. The password is not required. If you don't supply a password, Amazon Lex generates a zip file that is not protected by a password. This is the archive that is available at the pre-signed S3 URL provided by the operation.

    Args:
        export_id(str): The unique identifier Amazon Lex assigned to the export.
        file_password(str, optional): The new password to use to encrypt the export zip archive. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.export.update(ctx, export_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.export.update export_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="update_export",
        op_kwargs={"exportId": export_id, "filePassword": file_password},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    time_period: Dict,
    granularity: str = None,
    filter_: Dict = None,
    sort_by: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the Savings Plans utilization for your account across date ranges with daily or monthly granularity. Management account in an organization have access to member accounts. You can use GetDimensionValues in SAVINGS_PLANS to determine the possible dimension values.  You cannot group by any dimension values for GetSavingsPlansUtilization.

    Args:
        time_period(Dict): The time period that you want the usage and costs for. The Start date must be within 13 months. The End date must be after the Start date, and before the current date. Future dates can't be used as an End date.
        granularity(str, optional): The granularity of the Amazon Web Services utillization data for your Savings Plans. The GetSavingsPlansUtilization operation supports only DAILY and MONTHLY granularities. Defaults to None.
        filter_(Dict, optional): Filters Savings Plans utilization coverage data for active Savings Plans dimensions. You can filter data with the following dimensions:    LINKED_ACCOUNT     SAVINGS_PLAN_ARN     SAVINGS_PLANS_TYPE     REGION     PAYMENT_OPTION     INSTANCE_TYPE_FAMILY     GetSavingsPlansUtilization uses the same Expression object as the other operations, but only AND is supported among each dimension. Defaults to None.
        sort_by(Dict, optional): The value by which you want to sort the data. The following values are supported for Key:    UtilizationPercentage     TotalCommitment     UsedCommitment     UnusedCommitment     NetSavings    Supported values for SortOrder are ASCENDING or DESCENDING. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.saving_plan.utilization.init.get(ctx, time_period=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.saving_plan.utilization.init.get time_period=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_savings_plans_utilization",
        op_kwargs={
            "TimePeriod": time_period,
            "Granularity": granularity,
            "Filter": filter_,
            "SortBy": sort_by,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, namespace: str, metric_name: str, stat: str, dimensions: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified anomaly detection model from your account.

    Args:
        namespace(str): The namespace associated with the anomaly detection model to delete.
        metric_name(str): The metric name associated with the anomaly detection model to delete.
        dimensions(List, optional): The metric dimensions associated with the anomaly detection model to delete. Defaults to None.
        stat(str): The statistic associated with the anomaly detection model to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.anomaly_detector.delete(
                ctx, namespace=value, metric_name=value, stat=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.anomaly_detector.delete namespace=value, metric_name=value, stat=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="delete_anomaly_detector",
        op_kwargs={
            "Namespace": namespace,
            "MetricName": metric_name,
            "Dimensions": dimensions,
            "Stat": stat,
        },
    )


async def describe_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    namespace: str = None,
    metric_name: str = None,
    dimensions: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the anomaly detection models that you have created in your account. You can list all models in your account or filter the results to only the models that are related to a certain namespace, metric name, or metric dimension.

    Args:
        next_token(str, optional): Use the token returned by the previous operation to request the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in one operation. The maximum value that you can specify is 100. To retrieve the remaining results, make another call with the returned NextToken value. . Defaults to None.
        namespace(str, optional): Limits the results to only the anomaly detection models that are associated with the specified namespace. Defaults to None.
        metric_name(str, optional): Limits the results to only the anomaly detection models that are associated with the specified metric name. If there are multiple metrics with this name in different namespaces that have anomaly detection models, they're all returned. Defaults to None.
        dimensions(List, optional): Limits the results to only the anomaly detection models that are associated with the specified metric dimensions. If there are multiple metrics that have these dimensions and have anomaly detection models associated, they're all returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.anomaly_detector.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.anomaly_detector.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="describe_anomaly_detectors",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Namespace": namespace,
            "MetricName": metric_name,
            "Dimensions": dimensions,
        },
    )


async def put(
    hub,
    ctx,
    namespace: str,
    metric_name: str,
    stat: str,
    dimensions: List = None,
    configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an anomaly detection model for a CloudWatch metric. You can use the model to display a band of expected normal values when the metric is graphed. For more information, see CloudWatch Anomaly Detection.

    Args:
        namespace(str): The namespace of the metric to create the anomaly detection model for.
        metric_name(str): The name of the metric to create the anomaly detection model for.
        dimensions(List, optional): The metric dimensions to create the anomaly detection model for. Defaults to None.
        stat(str): The statistic to use for the metric and the anomaly detection model.
        configuration(Dict, optional): The configuration specifies details about how the anomaly detection model is to be trained, including time ranges to exclude when training and updating the model. You can specify as many as 10 time ranges. The configuration can also include the time zone to use for the metric. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.anomaly_detector.put(
                ctx, namespace=value, metric_name=value, stat=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.anomaly_detector.put namespace=value, metric_name=value, stat=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="put_anomaly_detector",
        op_kwargs={
            "Namespace": namespace,
            "MetricName": metric_name,
            "Dimensions": dimensions,
            "Stat": stat,
            "Configuration": configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    region_names: List = None,
    dry_run: bool = None,
    all_regions: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the Regions that are enabled for your account, or all Regions. For a list of the Regions supported by Amazon EC2, see  Regions and Endpoints. For information about enabling and disabling Regions for your account, see Managing AWS Regions in the AWS General Reference.

    Args:
        filters(List, optional): The filters.    endpoint - The endpoint of the Region (for example, ec2.us-east-1.amazonaws.com).    opt-in-status - The opt-in status of the Region (opt-in-not-required | opted-in | not-opted-in).    region-name - The name of the Region (for example, us-east-1).  . Defaults to None.
        region_names(List, optional): The names of the Regions. You can specify any Regions, whether they are enabled and disabled for your account. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        all_regions(bool, optional): Indicates whether to display all Regions, including Regions that are disabled for your account. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.region.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.region.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_regions",
        op_kwargs={
            "Filters": filters,
            "RegionNames": region_names,
            "DryRun": dry_run,
            "AllRegions": all_regions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub, ctx, organization_id: str, group_id: str, member_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a member (user or group) to the group's set.

    Args:
        organization_id(str): The organization under which the group exists.
        group_id(str): The group to which the member (user or group) is associated.
        member_id(str): The member (user or group) to associate to the group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.member.to_group.associate(
                ctx, organization_id=value, group_id=value, member_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.member.to_group.associate organization_id=value, group_id=value, member_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="associate_member_to_group",
        op_kwargs={
            "OrganizationId": organization_id,
            "GroupId": group_id,
            "MemberId": member_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    id_: str,
    packaging_group_id: str,
    cmaf_package: Dict = None,
    dash_package: Dict = None,
    hls_package: Dict = None,
    mss_package: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new MediaPackage VOD PackagingConfiguration resource.

    Args:
        cmaf_package(Dict, optional): A CMAF packaging configuration. Defaults to None.
        dash_package(Dict, optional): A Dynamic Adaptive Streaming over HTTP (DASH) packaging configuration. Defaults to None.
        hls_package(Dict, optional): An HTTP Live Streaming (HLS) packaging configuration. Defaults to None.
        id_(str): The ID of the PackagingConfiguration.
        mss_package(Dict, optional): A Microsoft Smooth Streaming (MSS) PackagingConfiguration. Defaults to None.
        packaging_group_id(str): The ID of a PackagingGroup.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.packaging.configuration.create(
                ctx, id_=value, packaging_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.packaging.configuration.create id_=value, packaging_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="create_packaging_configuration",
        op_kwargs={
            "CmafPackage": cmaf_package,
            "DashPackage": dash_package,
            "HlsPackage": hls_package,
            "Id": id_,
            "MssPackage": mss_package,
            "PackagingGroupId": packaging_group_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a MediaPackage VOD PackagingConfiguration resource.

    Args:
        id_(str): The ID of the MediaPackage VOD PackagingConfiguration resource to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.packaging.configuration.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.packaging.configuration.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="delete_packaging_configuration",
        op_kwargs={"Id": id_},
    )


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of a MediaPackage VOD PackagingConfiguration resource.

    Args:
        id_(str): The ID of a MediaPackage VOD PackagingConfiguration resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.packaging.configuration.describe(
                ctx, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.packaging.configuration.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="describe_packaging_configuration",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    packaging_group_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a collection of MediaPackage VOD PackagingConfiguration resources.

    Args:
        max_results(int, optional): Upper bound on number of records to return. Defaults to None.
        next_token(str, optional): A token used to resume pagination from the end of a previous request. Defaults to None.
        packaging_group_id(str, optional): Returns MediaPackage VOD PackagingConfigurations associated with the specified PackagingGroup. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.packaging.configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.packaging.configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="list_packaging_configurations",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "PackagingGroupId": packaging_group_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(
    hub,
    ctx,
    efs_filesystem_arn: str,
    ec2_config: Dict,
    subdirectory: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an endpoint for an Amazon EFS file system.

    Args:
        subdirectory(str, optional): A subdirectory in the location’s path. This subdirectory in the EFS file system is used to read data from the EFS source location or write data to the EFS destination. By default, AWS DataSync uses the root directory.   Subdirectory must be specified with forward slashes. For example, /path/to/folder. . Defaults to None.
        efs_filesystem_arn(str): The Amazon Resource Name (ARN) for the Amazon EFS file system.
        ec2_config(Dict): The subnet and security group that the Amazon EFS file system uses. The security group that you provide needs to be able to communicate with the security group on the mount target in the subnet specified. The exact relationship between security group M (of the mount target) and security group S (which you provide for DataSync to use at this stage) is as follows:     Security group M (which you associate with the mount target) must allow inbound access for the Transmission Control Protocol (TCP) on the NFS port (2049) from security group S. You can enable inbound connections either by IP address (CIDR range) or security group.    Security group S (provided to DataSync to access EFS) should have a rule that enables outbound connections to the NFS port on one of the file system’s mount targets. You can enable outbound connections either by IP address (CIDR range) or security group. For information about security groups and mount targets, see Security Groups for Amazon EC2 Instances and Mount Targets in the Amazon EFS User Guide.   .
        tags(List, optional): The key-value pair that represents a tag that you want to add to the resource. The value can be an empty string. This value helps you manage, filter, and search for your resources. We recommend that you create a name tag for your location. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.ef.create_multiple(
                ctx, efs_filesystem_arn=value, ec2_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.ef.create_multiple efs_filesystem_arn=value, ec2_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="create_location_efs",
        op_kwargs={
            "Subdirectory": subdirectory,
            "EfsFilesystemArn": efs_filesystem_arn,
            "Ec2Config": ec2_config,
            "Tags": tags,
        },
    )


async def describe_all(hub, ctx, location_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata, such as the path information about an Amazon EFS location.

    Args:
        location_arn(str): The Amazon Resource Name (ARN) of the EFS location to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.ef.describe_all(ctx, location_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.ef.describe_all location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="describe_location_efs",
        op_kwargs={"LocationArn": location_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, eula_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get Eula.

    Args:
        eula_id(str): The EULA ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.eula.init.get(ctx, eula_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.eula.init.get eula_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="nimble", operation="get_eula", op_kwargs={"eulaId": eula_id}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    filters: List = None,
    instance_ids: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
    include_all_instances: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the status of the specified instances or all of your instances. By default, only running instances are described, unless you specifically indicate to return the status of all instances. Instance status includes the following components:    Status checks - Amazon EC2 performs status checks on running EC2 instances to identify hardware and software issues. For more information, see Status checks for your instances and Troubleshooting instances with failed status checks in the Amazon EC2 User Guide.    Scheduled events - Amazon EC2 can schedule events (such as reboot, stop, or terminate) for your instances related to hardware issues, software updates, or system maintenance. For more information, see Scheduled events for your instances in the Amazon EC2 User Guide.    Instance state - You can manage your instances from the moment you launch them through their termination. For more information, see Instance lifecycle in the Amazon EC2 User Guide.

    Args:
        filters(List, optional): The filters.    availability-zone - The Availability Zone of the instance.    event.code - The code for the scheduled event (instance-reboot | system-reboot | system-maintenance | instance-retirement | instance-stop).    event.description - A description of the event.    event.instance-event-id - The ID of the event whose date and time you are modifying.    event.not-after - The latest end time for the scheduled event (for example, 2014-09-15T17:15:20.000Z).    event.not-before - The earliest start time for the scheduled event (for example, 2014-09-15T17:15:20.000Z).    event.not-before-deadline - The deadline for starting the event (for example, 2014-09-15T17:15:20.000Z).    instance-state-code - The code for the instance state, as a 16-bit unsigned integer. The high byte is used for internal purposes and should be ignored. The low byte is set based on the state represented. The valid values are 0 (pending), 16 (running), 32 (shutting-down), 48 (terminated), 64 (stopping), and 80 (stopped).    instance-state-name - The state of the instance (pending | running | shutting-down | terminated | stopping | stopped).    instance-status.reachability - Filters on instance status where the name is reachability (passed | failed | initializing | insufficient-data).    instance-status.status - The status of the instance (ok | impaired | initializing | insufficient-data | not-applicable).    system-status.reachability - Filters on system status where the name is reachability (passed | failed | initializing | insufficient-data).    system-status.status - The system status of the instance (ok | impaired | initializing | insufficient-data | not-applicable).  . Defaults to None.
        instance_ids(List, optional): The instance IDs. Default: Describes all your instances. Constraints: Maximum 100 explicitly specified instance IDs. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 5 and 1000. You cannot specify this parameter and the instance IDs parameter in the same call. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        include_all_instances(bool, optional): When true, includes the health status for all instances. When false, includes the health status for running instances only. Default: false . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.status.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.status.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_instance_status",
        op_kwargs={
            "Filters": filters,
            "InstanceIds": instance_ids,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
            "IncludeAllInstances": include_all_instances,
        },
    )


async def report(
    hub,
    ctx,
    instances: List,
    reason_codes: List,
    status: str,
    description: str = None,
    dry_run: bool = None,
    end_time: str = None,
    start_time: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Submits feedback about the status of an instance. The instance must be in the running state. If your experience with the instance differs from the instance status returned by DescribeInstanceStatus, use ReportInstanceStatus to report your experience with the instance. Amazon EC2 collects this information to improve the accuracy of status checks. Use of this action does not change the value returned by DescribeInstanceStatus.

    Args:
        description(str, optional): Descriptive text about the health state of your instance. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        end_time(str, optional): The time at which the reported instance health state ended. Defaults to None.
        instances(List): The instances.
        reason_codes(List): The reason codes that describe the health state of your instance.    instance-stuck-in-state: My instance is stuck in a state.    unresponsive: My instance is unresponsive.    not-accepting-credentials: My instance is not accepting my credentials.    password-not-available: A password is not available for my instance.    performance-network: My instance is experiencing performance problems that I believe are network related.    performance-instance-store: My instance is experiencing performance problems that I believe are related to the instance stores.    performance-ebs-volume: My instance is experiencing performance problems that I believe are related to an EBS volume.    performance-other: My instance is experiencing performance problems.    other: [explain using the description parameter]  .
        start_time(str, optional): The time at which the reported instance health state began. Defaults to None.
        status(str): The status of all instances listed.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.status.report(
                ctx, instances=value, reason_codes=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.status.report instances=value, reason_codes=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="report_instance_status",
        op_kwargs={
            "Description": description,
            "DryRun": dry_run,
            "EndTime": end_time,
            "Instances": instances,
            "ReasonCodes": reason_codes,
            "StartTime": start_time,
            "Status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    patch_group: str,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the high-level patch state for the instances in the specified patch group.

    Args:
        patch_group(str): The name of the patch group for which the patch state information should be retrieved.
        filters(List, optional): Each entry in the array is a structure containing:   Key (string between 1 and 200 characters)   Values (array containing a single string)   Type (string "Equal", "NotEqual", "LessThan", "GreaterThan")  . Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_results(int, optional): The maximum number of patches to return (per page). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.instance.patch.state.for_patch_group.describe(
                ctx, patch_group=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.instance.patch.state.for_patch_group.describe patch_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_instance_patch_states_for_patch_group",
        op_kwargs={
            "PatchGroup": patch_group,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def predict(
    hub, ctx, ml_model_id: str, record: Dict, predict_endpoint: str
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a prediction for the observation using the specified ML Model.  Note: Not all response parameters will be populated. Whether a response parameter is populated depends on the type of model requested.

    Args:
        ml_model_id(str): A unique identifier of the MLModel.
        record(Dict): A map of variable name-value pairs that represent an observation.
        predict_endpoint(str): .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.init.predict(
                ctx, ml_model_id=value, record=value, predict_endpoint=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.init.predict ml_model_id=value, record=value, predict_endpoint=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="predict",
        op_kwargs={
            "MLModelId": ml_model_id,
            "Record": record,
            "PredictEndpoint": predict_endpoint,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Add tags to the specified Amazon SNS topic. For an overview, see Amazon SNS Tags in the Amazon SNS Developer Guide. When you use topic tags, keep the following guidelines in mind:   Adding more than 50 tags to a topic isn't recommended.   Tags don't have any semantic meaning. Amazon SNS interprets tags as character strings.   Tags are case-sensitive.   A new tag with a key identical to that of an existing tag overwrites the existing tag.   Tagging actions are limited to 10 TPS per account, per Region. If your application requires a higher throughput, file a technical support request.

    Args:
        resource_arn(str): The ARN of the topic to which to add tags.
        tags(List): The tags to be added to the specified topic. A tag consists of a required key and an optional value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Remove tags from the specified Amazon SNS topic. For an overview, see Amazon SNS Tags in the Amazon SNS Developer Guide.

    Args:
        resource_arn(str): The ARN of the topic from which to remove tags.
        tag_keys(List): The list of tag keys to remove from the specified topic.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, name: str, resource_arn: str, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Enables Shield Advanced for a specific Amazon Web Services resource. The resource can be an Amazon CloudFront distribution, Elastic Load Balancing load balancer, Global Accelerator accelerator, Elastic IP Address, or an Amazon Route 53 hosted zone. You can add protection to only a single resource with each CreateProtection request. If you want to add protection to multiple resources at once, use the WAF console. For more information see Getting Started with Shield Advanced and Add Shield Advanced Protection to more Amazon Web Services Resources.

    Args:
        name(str): Friendly name for the Protection you are creating.
        resource_arn(str): The ARN (Amazon Resource Name) of the resource to be protected. The ARN should be in one of the following formats:   For an Application Load Balancer: arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id     For an Elastic Load Balancer (Classic Load Balancer): arn:aws:elasticloadbalancing:region:account-id:loadbalancer/load-balancer-name     For an Amazon CloudFront distribution: arn:aws:cloudfront::account-id:distribution/distribution-id     For an Global Accelerator accelerator: arn:aws:globalaccelerator::account-id:accelerator/accelerator-id     For Amazon Route 53: arn:aws:route53:::hostedzone/hosted-zone-id     For an Elastic IP address: arn:aws:ec2:region:account-id:eip-allocation/allocation-id    .
        tags(List, optional): One or more tag key-value pairs for the Protection object that is created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.protection.init.create(
                ctx, name=value, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.protection.init.create name=value, resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="create_protection",
        op_kwargs={"Name": name, "ResourceArn": resource_arn, "Tags": tags},
    )


async def delete(hub, ctx, protection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Shield Advanced Protection.

    Args:
        protection_id(str): The unique identifier (ID) for the Protection object to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.protection.init.delete(ctx, protection_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.protection.init.delete protection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="delete_protection",
        op_kwargs={"ProtectionId": protection_id},
    )


async def describe(
    hub, ctx, protection_id: str = None, resource_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the details of a Protection object.

    Args:
        protection_id(str, optional): The unique identifier (ID) for the Protection object that is described. When submitting the DescribeProtection request you must provide either the ResourceArn or the ProtectionID, but not both. Defaults to None.
        resource_arn(str, optional): The ARN (Amazon Resource Name) of the Amazon Web Services resource for the Protection object that is described. When submitting the DescribeProtection request you must provide either the ResourceArn or the ProtectionID, but not both. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.protection.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.protection.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="describe_protection",
        op_kwargs={"ProtectionId": protection_id, "ResourceArn": resource_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all Protection objects for the account.

    Args:
        next_token(str, optional): The ListProtectionsRequest.NextToken value from a previous call to ListProtections. Pass null if this is the first call. Defaults to None.
        max_results(int, optional): The maximum number of Protection objects to return. If you leave this blank, Shield Advanced returns the first 20 results. This is a maximum value. Shield Advanced might return the results in smaller batches. That is, the number of objects returned could be less than MaxResults, even if there are still more objects yet to return. If there are more objects to return, Shield Advanced returns a value in NextToken that you can use in your next request, to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.protection.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.protection.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="list_protections",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all categories in the Alexa skill store.

    Args:
        next_token(str, optional): The tokens used for pagination. Defaults to None.
        max_results(int, optional): The maximum number of categories returned, per paginated calls. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.store.category.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.store.category.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="list_skills_store_categories",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns details about an anomaly that you specify using its ID.

    Args:
        id_(str):  The ID of the anomaly. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.anomaly.init.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.anomaly.init.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="describe_anomaly",
        op_kwargs={"Id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, fleet_ids: List = None, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves core fleet-wide properties, including the computing hardware and deployment configuration for all instances in the fleet. This operation can be used in the following ways:    To get attributes for one or more specific fleets, provide a list of fleet IDs or fleet ARNs.    To get attributes for all fleets, do not provide a fleet identifier.    When requesting attributes for multiple fleets, use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a FleetAttributes object is returned for each fleet requested, unless the fleet identifier is not found.   Some API operations limit the number of fleet IDs that allowed in one request. If a request exceeds this limit, the request fails and the error message contains the maximum allowed number.   Learn more   Setting up GameLift fleets   Related actions   ListFleets | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetCapacity | DescribeFleetEvents | DescribeFleetLocationAttributes | DescribeFleetPortSettings | DescribeFleetUtilization | DescribeRuntimeConfiguration | DescribeScalingPolicies | All APIs by task

    Args:
        fleet_ids(List, optional): A list of unique fleet identifiers to retrieve attributes for. You can use either the fleet ID or ARN value. To retrieve attributes for all current fleets, do not include this parameter. . Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. This parameter is ignored when the request specifies one or a list of fleet IDs. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. This parameter is ignored when the request specifies one or a list of fleet IDs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.attribute.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.attribute.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_fleet_attributes",
        op_kwargs={"FleetIds": fleet_ids, "Limit": limit, "NextToken": next_token},
    )


async def update_multiple(
    hub,
    ctx,
    fleet_id: str,
    name: str = None,
    description: str = None,
    new_game_session_protection_policy: str = None,
    resource_creation_limit_policy: Dict = None,
    metric_groups: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a fleet's mutable attributes, including game session protection and resource creation limits. To update fleet attributes, specify the fleet ID and the property values that you want to change.  If successful, an updated FleetAttributes object is returned.  Learn more   Setting up GameLift fleets   Related actions   CreateFleetLocations | UpdateFleetAttributes | UpdateFleetCapacity | UpdateFleetPortSettings | UpdateRuntimeConfiguration | StopFleetActions | StartFleetActions | PutScalingPolicy | DeleteFleet | DeleteFleetLocations | DeleteScalingPolicy | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to update attribute metadata for. You can use either the fleet ID or ARN value.
        name(str, optional): A descriptive label that is associated with a fleet. Fleet names do not need to be unique. Defaults to None.
        description(str, optional): A human-readable description of a fleet. Defaults to None.
        new_game_session_protection_policy(str, optional): The game session protection policy to apply to all new instances created in this fleet. Instances that already exist are not affected. You can set protection for individual instances using UpdateGameSession.    NoProtection -- The game session can be terminated during a scale-down event.    FullProtection -- If the game session is in an ACTIVE status, it cannot be terminated during a scale-down event.  . Defaults to None.
        resource_creation_limit_policy(Dict, optional): Policy settings that limit the number of game sessions an individual player can create over a span of time. . Defaults to None.
        metric_groups(List, optional): The name of a metric group to add this fleet to. Use a metric group in Amazon CloudWatch to aggregate the metrics from multiple fleets. Provide an existing metric group name, or create a new metric group by providing a new name. A fleet can only be in one metric group at a time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.attribute.update_multiple(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.attribute.update_multiple fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_fleet_attributes",
        op_kwargs={
            "FleetId": fleet_id,
            "Name": name,
            "Description": description,
            "NewGameSessionProtectionPolicy": new_game_session_protection_policy,
            "ResourceCreationLimitPolicy": resource_creation_limit_policy,
            "MetricGroups": metric_groups,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, stack_drift_detection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a stack drift detection operation. A stack drift detection operation detects whether a stack's actual configuration differs, or has drifted, from it's expected configuration, as defined in the stack template and any values specified as template parameters. A stack is considered to have drifted if one or more of its resources have drifted. For more information on stack and resource drift, see Detecting Unregulated Configuration Changes to Stacks and Resources. Use DetectStackDrift to initiate a stack drift detection operation. DetectStackDrift returns a StackDriftDetectionId you can use to monitor the progress of the operation using DescribeStackDriftDetectionStatus. Once the drift detection operation has completed, use DescribeStackResourceDrifts to return drift information about the stack and its resources.

    Args:
        stack_drift_detection_id(str): The ID of the drift detection results of this operation.  CloudFormation generates new results, with a new drift detection ID, each time this operation is run. However, the number of drift results CloudFormation retains for any given stack, and for how long, may vary. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.drift.detection_status.describe(
                ctx, stack_drift_detection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.drift.detection_status.describe stack_drift_detection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="describe_stack_drift_detection_status",
        op_kwargs={"StackDriftDetectionId": stack_drift_detection_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, event_arns: List, locale: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about one or more specified events. Information includes standard event data (AWS Region, service, and so on, as returned by DescribeEvents), a detailed event description, and possible additional metadata that depends upon the nature of the event. Affected entities are not included. To retrieve the entities, use the DescribeAffectedEntities operation. If a specified event can't be retrieved, an error message is returned for that event.  This operation supports resource-level permissions. You can use this operation to allow or deny access to specific AWS Health events. For more information, see Resource- and action-based conditions in the AWS Health User Guide.

    Args:
        event_arns(List): A list of event ARNs (unique identifiers). For example: "arn:aws:health:us-east-1::event/EC2/EC2_INSTANCE_RETIREMENT_SCHEDULED/EC2_INSTANCE_RETIREMENT_SCHEDULED_ABC123-CDE456", "arn:aws:health:us-west-1::event/EBS/AWS_EBS_LOST_VOLUME/AWS_EBS_LOST_VOLUME_CHI789_JKL101" .
        locale(str, optional): The locale (language) to return information in. English (en) is the default and the only supported value at this time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.event.detail.init.describe_all(ctx, event_arns=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.event.detail.init.describe_all event_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_event_details",
        op_kwargs={"eventArns": event_arns, "locale": locale},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, validity: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a URL to start an image builder streaming session.

    Args:
        name(str): The name of the image builder.
        validity(int, optional): The time that the streaming URL will be valid, in seconds. Specify a value between 1 and 604800 seconds. The default is 3600 seconds. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.builder.streaming_url.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.builder.streaming_url.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="create_image_builder_streaming_url",
        op_kwargs={"Name": name, "Validity": validity},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub,
    ctx,
    instance_id: str,
    instance_os_user: str,
    ssh_public_key: str,
    availability_zone: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Pushes an SSH public key to the specified EC2 instance for use by the specified user. The key remains for 60 seconds. For more information, see Connect to your Linux instance using EC2 Instance Connect in the Amazon EC2 User Guide.

    Args:
        instance_id(str): The ID of the EC2 instance.
        instance_os_user(str): The OS user on the EC2 instance for whom the key can be used to authenticate.
        ssh_public_key(str): The public key material. To use the public key, you must have the matching private key.
        availability_zone(str): The Availability Zone in which the EC2 instance was launched.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2_instance_connect.ssh_public_key.send(
                ctx,
                instance_id=value,
                instance_os_user=value,
                ssh_public_key=value,
                availability_zone=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2_instance_connect.ssh_public_key.send instance_id=value, instance_os_user=value, ssh_public_key=value, availability_zone=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2-instance-connect",
        operation="send_ssh_public_key",
        op_kwargs={
            "InstanceId": instance_id,
            "InstanceOSUser": instance_os_user,
            "SSHPublicKey": ssh_public_key,
            "AvailabilityZone": availability_zone,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, reservation_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays the details of a reservation. The response includes the reservation name, state, start date and time, and the details of the offering that make up the rest of the reservation (such as price, duration, and outbound bandwidth).

    Args:
        reservation_arn(str): The Amazon Resource Name (ARN) of the reservation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.reservation.describe(ctx, reservation_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.reservation.describe reservation_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="describe_reservation",
        op_kwargs={"ReservationArn": reservation_arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Displays a list of all reservations that have been purchased by this account in the current AWS Region. This list includes all reservations in all states (such as active and expired).

    Args:
        max_results(int, optional): The maximum number of results to return per API request. For example, you submit a ListReservations request with MaxResults set at 5. Although 20 items match your request, the service returns no more than the first 5 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.) The service might return fewer results than the MaxResults value. If MaxResults is not included in the request, the service defaults to pagination with a maximum of 10 results per page. Defaults to None.
        next_token(str, optional): The token that identifies which batch of results that you want to see. For example, you submit a ListReservations request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the ListOfferings request a second time and specify the NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.reservation.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.reservation.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="list_reservations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_snapshot_identifier: str,
    target_snapshot_identifier: str,
    source_snapshot_cluster_identifier: str = None,
    manual_snapshot_retention_period: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies the specified automated cluster snapshot to a new manual cluster snapshot. The source must be an automated snapshot and it must be in the available state. When you delete a cluster, Amazon Redshift deletes any automated snapshots of the cluster. Also, when the retention period of the snapshot expires, Amazon Redshift automatically deletes it. If you want to keep an automated snapshot for a longer period, you can make a manual copy of the snapshot. Manual snapshots are retained until you delete them.  For more information about working with snapshots, go to Amazon Redshift Snapshots in the Amazon Redshift Cluster Management Guide.

    Args:
        source_snapshot_identifier(str): The identifier for the source snapshot. Constraints:   Must be the identifier for a valid automated snapshot whose state is available.  .
        source_snapshot_cluster_identifier(str, optional): The identifier of the cluster the source snapshot was created from. This parameter is required if your IAM user has a policy containing a snapshot resource element that specifies anything other than * for the cluster name. Constraints:   Must be the identifier for a valid cluster.  . Defaults to None.
        target_snapshot_identifier(str): The identifier given to the new manual snapshot. Constraints:   Cannot be null, empty, or blank.   Must contain from 1 to 255 alphanumeric characters or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Must be unique for the Amazon Web Services account that is making the request.  .
        manual_snapshot_retention_period(int, optional): The number of days that a manual snapshot is retained. If the value is -1, the manual snapshot is retained indefinitely.  The value must be either -1 or an integer between 1 and 3,653. The default value is -1. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.snapshot.init.copy(
                ctx, source_snapshot_identifier=value, target_snapshot_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.snapshot.init.copy source_snapshot_identifier=value, target_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="copy_cluster_snapshot",
        op_kwargs={
            "SourceSnapshotIdentifier": source_snapshot_identifier,
            "SourceSnapshotClusterIdentifier": source_snapshot_cluster_identifier,
            "TargetSnapshotIdentifier": target_snapshot_identifier,
            "ManualSnapshotRetentionPeriod": manual_snapshot_retention_period,
        },
    )


async def create(
    hub,
    ctx,
    snapshot_identifier: str,
    cluster_identifier: str,
    manual_snapshot_retention_period: int = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a manual snapshot of the specified cluster. The cluster must be in the available state.   For more information about working with snapshots, go to Amazon Redshift Snapshots in the Amazon Redshift Cluster Management Guide.

    Args:
        snapshot_identifier(str): A unique identifier for the snapshot that you are requesting. This identifier must be unique for all snapshots within the Amazon Web Services account. Constraints:   Cannot be null, empty, or blank   Must contain from 1 to 255 alphanumeric characters or hyphens   First character must be a letter   Cannot end with a hyphen or contain two consecutive hyphens   Example: my-snapshot-id .
        cluster_identifier(str): The cluster identifier for which you want a snapshot.
        manual_snapshot_retention_period(int, optional): The number of days that a manual snapshot is retained. If the value is -1, the manual snapshot is retained indefinitely.  The value must be either -1 or an integer between 1 and 3,653. The default value is -1. Defaults to None.
        tags(List, optional): A list of tag instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.snapshot.init.create(
                ctx, snapshot_identifier=value, cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.snapshot.init.create snapshot_identifier=value, cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_cluster_snapshot",
        op_kwargs={
            "SnapshotIdentifier": snapshot_identifier,
            "ClusterIdentifier": cluster_identifier,
            "ManualSnapshotRetentionPeriod": manual_snapshot_retention_period,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, snapshot_identifier: str, snapshot_cluster_identifier: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified manual snapshot. The snapshot must be in the available state, with no other users authorized to access the snapshot.  Unlike automated snapshots, manual snapshots are retained even after you delete your cluster. Amazon Redshift does not delete your manual snapshots. You must delete manual snapshot explicitly to avoid getting charged. If other accounts are authorized to access the snapshot, you must revoke all of the authorizations before you can delete the snapshot.

    Args:
        snapshot_identifier(str): The unique identifier of the manual snapshot to be deleted. Constraints: Must be the name of an existing snapshot that is in the available, failed, or cancelled state.
        snapshot_cluster_identifier(str, optional): The unique identifier of the cluster the snapshot was created from. This parameter is required if your IAM user has a policy containing a snapshot resource element that specifies anything other than * for the cluster name. Constraints: Must be the name of valid cluster. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.snapshot.init.delete(
                ctx, snapshot_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.snapshot.init.delete snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_cluster_snapshot",
        op_kwargs={
            "SnapshotIdentifier": snapshot_identifier,
            "SnapshotClusterIdentifier": snapshot_cluster_identifier,
        },
    )


async def describe_all(
    hub,
    ctx,
    cluster_identifier: str = None,
    snapshot_identifier: str = None,
    snapshot_type: str = None,
    start_time: str = None,
    end_time: str = None,
    max_records: int = None,
    marker: str = None,
    owner_account: str = None,
    tag_keys: List = None,
    tag_values: List = None,
    cluster_exists: bool = None,
    sorting_entities: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns one or more snapshot objects, which contain metadata about your cluster snapshots. By default, this operation returns information about all snapshots of all clusters that are owned by your Amazon Web Services account. No information is returned for snapshots owned by inactive Amazon Web Services accounts. If you specify both tag keys and tag values in the same request, Amazon Redshift returns all snapshots that match any combination of the specified keys and values. For example, if you have owner and environment for tag keys, and admin and test for tag values, all snapshots that have any combination of those values are returned. Only snapshots that you own are returned in the response; shared snapshots are not returned with the tag key and tag value request parameters. If both tag keys and values are omitted from the request, snapshots are returned regardless of whether they have tag keys or values associated with them.

    Args:
        cluster_identifier(str, optional): The identifier of the cluster which generated the requested snapshots. Defaults to None.
        snapshot_identifier(str, optional): The snapshot identifier of the snapshot about which to return information. Defaults to None.
        snapshot_type(str, optional): The type of snapshots for which you are requesting information. By default, snapshots of all types are returned. Valid Values: automated | manual . Defaults to None.
        start_time(str, optional): A value that requests only snapshots created at or after the specified time. The time value is specified in ISO 8601 format. For more information about ISO 8601, go to the ISO8601 Wikipedia page.  Example: 2012-07-16T18:00:00Z . Defaults to None.
        end_time(str, optional): A time value that requests only snapshots created at or before the specified time. The time value is specified in ISO 8601 format. For more information about ISO 8601, go to the ISO8601 Wikipedia page.  Example: 2012-07-16T18:00:00Z . Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeClusterSnapshots request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.
        owner_account(str, optional): The Amazon Web Services account used to create or copy the snapshot. Use this field to filter the results to snapshots owned by a particular account. To describe snapshots you own, either specify your Amazon Web Services account, or do not specify the parameter. Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching cluster snapshots that are associated with the specified key or keys. For example, suppose that you have snapshots that are tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the snapshots that have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching cluster snapshots that are associated with the specified tag value or values. For example, suppose that you have snapshots that are tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with the snapshots that have either or both of these tag values associated with them. Defaults to None.
        cluster_exists(bool, optional): A value that indicates whether to return snapshots only for an existing cluster. You can perform table-level restore only by using a snapshot of an existing cluster, that is, a cluster that has not been deleted. Values for this parameter work as follows:    If ClusterExists is set to true, ClusterIdentifier is required.   If ClusterExists is set to false and ClusterIdentifier isn't specified, all snapshots associated with deleted clusters (orphaned snapshots) are returned.    If ClusterExists is set to false and ClusterIdentifier is specified for a deleted cluster, snapshots associated with that cluster are returned.   If ClusterExists is set to false and ClusterIdentifier is specified for an existing cluster, no snapshots are returned.   . Defaults to None.
        sorting_entities(List, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.snapshot.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.snapshot.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_cluster_snapshots",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "SnapshotIdentifier": snapshot_identifier,
            "SnapshotType": snapshot_type,
            "StartTime": start_time,
            "EndTime": end_time,
            "MaxRecords": max_records,
            "Marker": marker,
            "OwnerAccount": owner_account,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
            "ClusterExists": cluster_exists,
            "SortingEntities": sorting_entities,
        },
    )


async def modify(
    hub,
    ctx,
    snapshot_identifier: str,
    manual_snapshot_retention_period: int = None,
    force: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the settings for a snapshot. This exanmple modifies the manual retention period setting for a cluster snapshot.

    Args:
        snapshot_identifier(str): The identifier of the snapshot whose setting you want to modify.
        manual_snapshot_retention_period(int, optional): The number of days that a manual snapshot is retained. If the value is -1, the manual snapshot is retained indefinitely. If the manual snapshot falls outside of the new retention period, you can specify the force option to immediately delete the snapshot. The value must be either -1 or an integer between 1 and 3,653. Defaults to None.
        force(bool, optional): A Boolean option to override an exception if the retention period has already passed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.snapshot.init.modify(
                ctx, snapshot_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.snapshot.init.modify snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_cluster_snapshot",
        op_kwargs={
            "SnapshotIdentifier": snapshot_identifier,
            "ManualSnapshotRetentionPeriod": manual_snapshot_retention_period,
            "Force": force,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, tags: Dict = None, whitelist_rules: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Input Security Group

    Args:
        tags(Dict, optional): A collection of key-value pairs. Defaults to None.
        whitelist_rules(List, optional): List of IPv4 CIDR addresses to whitelist. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.security_group.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.security_group.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="create_input_security_group",
        op_kwargs={"Tags": tags, "WhitelistRules": whitelist_rules},
    )


async def delete(hub, ctx, input_security_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Input Security Group

    Args:
        input_security_group_id(str): The Input Security Group to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.security_group.delete(
                ctx, input_security_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.security_group.delete input_security_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="delete_input_security_group",
        op_kwargs={"InputSecurityGroupId": input_security_group_id},
    )


async def describe(hub, ctx, input_security_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Produces a summary of an Input Security Group

    Args:
        input_security_group_id(str): The id of the Input Security Group to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.security_group.describe(
                ctx, input_security_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.security_group.describe input_security_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="describe_input_security_group",
        op_kwargs={"InputSecurityGroupId": input_security_group_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Produces a list of Input Security Groups for an account

    Args:
        max_results(int, optional): Placeholder documentation for MaxResults. Defaults to None.
        next_token(str, optional): Placeholder documentation for __string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.security_group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.security_group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="list_input_security_groups",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    input_security_group_id: str,
    tags: Dict = None,
    whitelist_rules: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update an Input Security Group's Whilelists.

    Args:
        input_security_group_id(str): The id of the Input Security Group to update.
        tags(Dict, optional): A collection of key-value pairs. Defaults to None.
        whitelist_rules(List, optional): List of IPv4 CIDR addresses to whitelist. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.security_group.update(
                ctx, input_security_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.security_group.update input_security_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="update_input_security_group",
        op_kwargs={
            "InputSecurityGroupId": input_security_group_id,
            "Tags": tags,
            "WhitelistRules": whitelist_rules,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, setting_id: str) -> Dict:
    r"""
    **Autogenerated function**

     ServiceSetting is an account-level setting for an Amazon Web Services service. This setting defines how a user interacts with or uses a service or a feature of a service. For example, if an Amazon Web Services service charges money to the account based on feature or service usage, then the Amazon Web Services service team might create a default setting of false. This means the user can't use this feature unless they change the setting to true and intentionally opt in for a paid feature. Services map a SettingId object to a setting value. Amazon Web Services services teams define the default value for a SettingId. You can't create a new SettingId, but you can overwrite the default value if you have the ssm:UpdateServiceSetting permission for the setting. Use the UpdateServiceSetting API operation to change the default setting. Or use the ResetServiceSetting to change the value back to the original value defined by the Amazon Web Services service team. Query the current service setting for the account.

    Args:
        setting_id(str): The ID of the service setting to get. The setting ID can be one of the following.    /ssm/automation/customer-script-log-destination     /ssm/automation/customer-script-log-group-name     /ssm/documents/console/public-sharing-permission     /ssm/parameter-store/default-parameter-tier     /ssm/parameter-store/high-throughput-enabled     /ssm/managed-instance/activation-tier   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.service_setting.get(ctx, setting_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.service_setting.get setting_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_service_setting",
        op_kwargs={"SettingId": setting_id},
    )


async def reset(hub, ctx, setting_id: str) -> Dict:
    r"""
    **Autogenerated function**

     ServiceSetting is an account-level setting for an Amazon Web Services service. This setting defines how a user interacts with or uses a service or a feature of a service. For example, if an Amazon Web Services service charges money to the account based on feature or service usage, then the Amazon Web Services service team might create a default setting of "false". This means the user can't use this feature unless they change the setting to "true" and intentionally opt in for a paid feature. Services map a SettingId object to a setting value. Amazon Web Services services teams define the default value for a SettingId. You can't create a new SettingId, but you can overwrite the default value if you have the ssm:UpdateServiceSetting permission for the setting. Use the GetServiceSetting API operation to view the current value. Use the UpdateServiceSetting API operation to change the default setting.  Reset the service setting for the account to the default value as provisioned by the Amazon Web Services service team.

    Args:
        setting_id(str): The Amazon Resource Name (ARN) of the service setting to reset. The setting ID can be one of the following.    /ssm/automation/customer-script-log-destination     /ssm/automation/customer-script-log-group-name     /ssm/documents/console/public-sharing-permission     /ssm/parameter-store/default-parameter-tier     /ssm/parameter-store/high-throughput-enabled     /ssm/managed-instance/activation-tier   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.service_setting.reset(ctx, setting_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.service_setting.reset setting_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="reset_service_setting",
        op_kwargs={"SettingId": setting_id},
    )


async def update(hub, ctx, setting_id: str, setting_value: str) -> Dict:
    r"""
    **Autogenerated function**

     ServiceSetting is an account-level setting for an Amazon Web Services service. This setting defines how a user interacts with or uses a service or a feature of a service. For example, if an Amazon Web Services service charges money to the account based on feature or service usage, then the Amazon Web Services service team might create a default setting of "false". This means the user can't use this feature unless they change the setting to "true" and intentionally opt in for a paid feature. Services map a SettingId object to a setting value. Amazon Web Services services teams define the default value for a SettingId. You can't create a new SettingId, but you can overwrite the default value if you have the ssm:UpdateServiceSetting permission for the setting. Use the GetServiceSetting API operation to view the current value. Or, use the ResetServiceSetting to change the value back to the original value defined by the Amazon Web Services service team. Update the service setting for the account.

    Args:
        setting_id(str): The Amazon Resource Name (ARN) of the service setting to reset. For example, arn:aws:ssm:us-east-1:111122223333:servicesetting/ssm/parameter-store/high-throughput-enabled. The setting ID can be one of the following.    /ssm/automation/customer-script-log-destination     /ssm/automation/customer-script-log-group-name     /ssm/documents/console/public-sharing-permission     /ssm/parameter-store/default-parameter-tier     /ssm/parameter-store/high-throughput-enabled     /ssm/managed-instance/activation-tier   .
        setting_value(str): The new value to specify for the service setting. For the /ssm/parameter-store/default-parameter-tier setting ID, the setting value can be one of the following.   Standard   Advanced   Intelligent-Tiering   For the /ssm/parameter-store/high-throughput-enabled, and /ssm/managed-instance/activation-tier setting IDs, the setting value can be true or false. For the /ssm/automation/customer-script-log-destination setting ID, the setting value can be CloudWatch. For the /ssm/automation/customer-script-log-group-name setting ID, the setting value can be the name of an Amazon CloudWatch Logs log group. For the /ssm/documents/console/public-sharing-permission setting ID, the setting value can be Enable or Disable.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.service_setting.update(
                ctx, setting_id=value, setting_value=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.service_setting.update setting_id=value, setting_value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_service_setting",
        op_kwargs={"SettingId": setting_id, "SettingValue": setting_value},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, group_id: List, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    [VPC only] Describes the VPCs on the other side of a VPC peering connection that are referencing the security groups you've specified in this request.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        group_id(List): The IDs of the security groups in your account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.reference.describe_all(ctx, group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.reference.describe_all group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_security_group_references",
        op_kwargs={"DryRun": dry_run, "GroupId": group_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str = None,
    version: str = None,
    storage_location: Dict = None,
    operating_system: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon GameLift build resource for your game server binary files. Game server binaries must be combined into a zip file for use with Amazon GameLift.   When setting up a new game build for GameLift, we recommend using the AWS CLI command  upload-build . This helper command combines two tasks: (1) it uploads your build files from a file directory to a GameLift Amazon S3 location, and (2) it creates a new build resource.   The CreateBuild operation can used in the following scenarios:   To create a new game build with build files that are in an Amazon S3 location under an AWS account that you control. To use this option, you must first give Amazon GameLift access to the Amazon S3 bucket. With permissions in place, call CreateBuild and specify a build name, operating system, and the Amazon S3 storage location of your game build.   To directly upload your build files to a GameLift Amazon S3 location. To use this option, first call CreateBuild and specify a build name and operating system. This operation creates a new build resource and also returns an Amazon S3 location with temporary access credentials. Use the credentials to manually upload your build files to the specified Amazon S3 location. For more information, see Uploading Objects in the Amazon S3 Developer Guide. Build files can be uploaded to the GameLift Amazon S3 location once only; that can't be updated.    If successful, this operation creates a new build resource with a unique build ID and places it in INITIALIZED status. A build must be in READY status before you can create fleets with it.  Learn more   Uploading Your Game    Create a Build with Files in Amazon S3   Related actions   CreateBuild | ListBuilds | DescribeBuild | UpdateBuild | DeleteBuild | All APIs by task

    Args:
        name(str, optional): A descriptive label that is associated with a build. Build names do not need to be unique. You can use UpdateBuild to change this value later. . Defaults to None.
        version(str, optional): Version information that is associated with a build or script. Version strings do not need to be unique. You can use UpdateBuild to change this value later. . Defaults to None.
        storage_location(Dict, optional): Information indicating where your game build files are stored. Use this parameter only when creating a build with files stored in an Amazon S3 bucket that you own. The storage location must specify an Amazon S3 bucket name and key. The location must also specify a role ARN that you set up to allow Amazon GameLift to access your Amazon S3 bucket. The S3 bucket and your new build must be in the same Region. Defaults to None.
        operating_system(str, optional): The operating system that the game server binaries are built to run on. This value determines the type of fleet resources that you can use for this build. If your game build contains multiple executables, they all must run on the same operating system. If an operating system is not specified when creating a build, Amazon GameLift uses the default value (WINDOWS_2012). This value cannot be changed later. Defaults to None.
        tags(List, optional): A list of labels to assign to the new build resource. Tags are developer-defined key-value pairs. Tagging AWS resources are useful for resource management, access management and cost allocation. For more information, see  Tagging AWS Resources in the AWS General Reference. Once the resource is created, you can use TagResource, UntagResource, and ListTagsForResource to add, remove, and view tags. The maximum tag limit may be lower than stated. See the AWS General Reference for actual tagging limits. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.build.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.build.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_build",
        op_kwargs={
            "Name": name,
            "Version": version,
            "StorageLocation": storage_location,
            "OperatingSystem": operating_system,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, build_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a build. This operation permanently deletes the build resource and any uploaded build files. Deleting a build does not affect the status of any active fleets using the build, but you can no longer create new fleets with the deleted build. To delete a build, specify the build ID.   Learn more    Upload a Custom Server Build   Related actions   CreateBuild | ListBuilds | DescribeBuild | UpdateBuild | DeleteBuild | All APIs by task

    Args:
        build_id(str): A unique identifier for the build to delete. You can use either the build ID or ARN value. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.build.delete(ctx, build_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.build.delete build_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_build",
        op_kwargs={"BuildId": build_id},
    )


async def describe(hub, ctx, build_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves properties for a custom game build. To request a build resource, specify a build ID. If successful, an object containing the build properties is returned.  Learn more    Upload a Custom Server Build   Related actions   CreateBuild | ListBuilds | DescribeBuild | UpdateBuild | DeleteBuild | All APIs by task

    Args:
        build_id(str): A unique identifier for the build to retrieve properties for. You can use either the build ID or ARN value. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.build.describe(ctx, build_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.build.describe build_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_build",
        op_kwargs={"BuildId": build_id},
    )


async def list_all(
    hub, ctx, status: str = None, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves build resources for all builds associated with the AWS account in use. You can limit results to builds that are in a specific status by using the Status parameter. Use the pagination parameters to retrieve results in a set of sequential pages.   Build resources are not listed in any particular order.   Learn more    Upload a Custom Server Build   Related actions   CreateBuild | ListBuilds | DescribeBuild | UpdateBuild | DeleteBuild | All APIs by task

    Args:
        status(str, optional): Build status to filter results by. To retrieve all builds, leave this parameter empty. Possible build statuses include the following:    INITIALIZED -- A new build has been defined, but no files have been uploaded. You cannot create fleets for builds that are in this status. When a build is successfully created, the build status is set to this value.     READY -- The game build has been successfully uploaded. You can now create new fleets for this build.    FAILED -- The game build upload failed. You cannot create new fleets for this build.   . Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.build.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.build.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="list_builds",
        op_kwargs={"Status": status, "Limit": limit, "NextToken": next_token},
    )


async def update(
    hub, ctx, build_id: str, name: str = None, version: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates metadata in a build resource, including the build name and version. To update the metadata, specify the build ID to update and provide the new values. If successful, a build object containing the updated metadata is returned.  Learn more    Upload a Custom Server Build   Related actions   CreateBuild | ListBuilds | DescribeBuild | UpdateBuild | DeleteBuild | All APIs by task

    Args:
        build_id(str): A unique identifier for the build to update. You can use either the build ID or ARN value. .
        name(str, optional): A descriptive label that is associated with a build. Build names do not need to be unique. . Defaults to None.
        version(str, optional): Version information that is associated with a build or script. Version strings do not need to be unique. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.build.update(ctx, build_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.build.update build_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_build",
        op_kwargs={"BuildId": build_id, "Name": name, "Version": version},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "to_stack_set"


__func_alias__ = {"import_": "import"}


async def import_(
    hub,
    ctx,
    stack_set_name: str,
    stack_ids: List,
    operation_preferences: Dict = None,
    operation_id: str = None,
    call_as: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Import existing stacks into a new stack sets. Use the stack import operation to import up to 10 stacks into a new stack set in the same account as the source stack or in a different administrator account and Region, by specifying the stack ID of the stack you intend to import.   ImportStacksToStackSet is only supported by self-managed permissions.

    Args:
        stack_set_name(str): The name of the stack set. The name must be unique in the Region where you create your stack set.
        stack_ids(List): The IDs of the stacks you are importing into a stack set. You import up to 10 stacks per stack set at a time.
        operation_preferences(Dict, optional): The user-specified preferences for how CloudFormation performs a stack set operation.  For more information on maximum concurrent accounts and failure tolerance, see Stack set operation options. Defaults to None.
        operation_id(str, optional): A unique, user defined, identifier for the stack set operation. Defaults to None.
        call_as(str, optional): By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   For service managed stack sets, specify DELEGATED_ADMIN.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.to_stack_set_.import(ctx, stack_set_name=value, stack_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.to_stack_set.import stack_set_name=value, stack_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="import_stacks_to_stack_set",
        op_kwargs={
            "StackSetName": stack_set_name,
            "StackIds": stack_ids,
            "OperationPreferences": operation_preferences,
            "OperationId": operation_id,
            "CallAs": call_as,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, workload_id: str, lens_alias: str, milestone_number: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Get lens review report.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        lens_alias(str): The alias of the lens, for example, serverless. Each lens is identified by its LensSummary$LensAlias.
        milestone_number(int, optional): The milestone number. A workload can have a maximum of 100 milestones. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.lens.review.report.get(
                ctx, workload_id=value, lens_alias=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.lens.review.report.get workload_id=value, lens_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="get_lens_review_report",
        op_kwargs={
            "WorkloadId": workload_id,
            "LensAlias": lens_alias,
            "MilestoneNumber": milestone_number,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "metric_set"


async def create(
    hub,
    ctx,
    anomaly_detector_arn: str,
    metric_set_name: str,
    metric_list: List,
    metric_source: Dict,
    metric_set_description: str = None,
    offset: int = None,
    timestamp_column: Dict = None,
    dimension_list: List = None,
    metric_set_frequency: str = None,
    timezone: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a dataset.

    Args:
        anomaly_detector_arn(str): The ARN of the anomaly detector that will use the dataset.
        metric_set_name(str): The name of the dataset.
        metric_set_description(str, optional): A description of the dataset you are creating. Defaults to None.
        metric_list(List): A list of metrics that the dataset will contain.
        offset(int, optional): After an interval ends, the amount of seconds that the detector waits before importing data. Offset is only supported for S3 and Redshift datasources. Defaults to None.
        timestamp_column(Dict, optional): Contains information about the column used for tracking time in your source data. Defaults to None.
        dimension_list(List, optional): A list of the fields you want to treat as dimensions. Defaults to None.
        metric_set_frequency(str, optional): The frequency with which the source data will be analyzed for anomalies. Defaults to None.
        metric_source(Dict): Contains information about how the source data should be interpreted.
        timezone(str, optional): The time zone in which your source data was recorded. Defaults to None.
        tags(Dict, optional): A list of tags to apply to the dataset. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.metric_set_.create(
                ctx,
                anomaly_detector_arn=value,
                metric_set_name=value,
                metric_list=value,
                metric_source=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.metric_set.create anomaly_detector_arn=value, metric_set_name=value, metric_list=value, metric_source=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="create_metric_set",
        op_kwargs={
            "AnomalyDetectorArn": anomaly_detector_arn,
            "MetricSetName": metric_set_name,
            "MetricSetDescription": metric_set_description,
            "MetricList": metric_list,
            "Offset": offset,
            "TimestampColumn": timestamp_column,
            "DimensionList": dimension_list,
            "MetricSetFrequency": metric_set_frequency,
            "MetricSource": metric_source,
            "Timezone": timezone,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, metric_set_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a dataset. Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.

    Args:
        metric_set_arn(str): The ARN of the dataset.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.metric_set_.describe(ctx, metric_set_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.metric_set.describe metric_set_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="describe_metric_set",
        op_kwargs={"MetricSetArn": metric_set_arn},
    )


async def list_all(
    hub,
    ctx,
    anomaly_detector_arn: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the datasets in the current AWS Region. Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.

    Args:
        anomaly_detector_arn(str, optional): The ARN of the anomaly detector containing the metrics sets to list. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): If the result of the previous request was truncated, the response includes a NextToken. To retrieve the next set of results, use the token in the next request. Tokens expire after 24 hours. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.metric_set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.metric_set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="list_metric_sets",
        op_kwargs={
            "AnomalyDetectorArn": anomaly_detector_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    metric_set_arn: str,
    metric_set_description: str = None,
    metric_list: List = None,
    offset: int = None,
    timestamp_column: Dict = None,
    dimension_list: List = None,
    metric_set_frequency: str = None,
    metric_source: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a dataset.

    Args:
        metric_set_arn(str): The ARN of the dataset to update.
        metric_set_description(str, optional): The dataset's description. Defaults to None.
        metric_list(List, optional): The metric list. Defaults to None.
        offset(int, optional): After an interval ends, the amount of seconds that the detector waits before importing data. Offset is only supported for S3 and Redshift datasources. Defaults to None.
        timestamp_column(Dict, optional): The timestamp column. Defaults to None.
        dimension_list(List, optional): The dimension list. Defaults to None.
        metric_set_frequency(str, optional): The dataset's interval. Defaults to None.
        metric_source(Dict, optional): Contains information about source data used to generate a metric. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.metric_set_.update(ctx, metric_set_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.metric_set.update metric_set_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="update_metric_set",
        op_kwargs={
            "MetricSetArn": metric_set_arn,
            "MetricSetDescription": metric_set_description,
            "MetricList": metric_list,
            "Offset": offset,
            "TimestampColumn": timestamp_column,
            "DimensionList": dimension_list,
            "MetricSetFrequency": metric_set_frequency,
            "MetricSource": metric_source,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def peer(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Peers the Lightsail VPC with the user's default VPC.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.vpc.init.peer(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.vpc.init.peer
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="lightsail", operation="peer_vpc", op_kwargs={}
    )


async def unpeer(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Unpeers the Lightsail VPC from the user's default VPC.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.vpc.init.unpeer(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.vpc.init.unpeer
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="lightsail", operation="unpeer_vpc", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(hub, ctx, detector_id: str, account_details: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates member accounts of the current AWS account by specifying a list of AWS account IDs. This step is a prerequisite for managing the associated member accounts either by invitation or through an organization. When using Create Members as an organizations delegated administrator this action will enable GuardDuty in the added member accounts, with the exception of the organization delegated administrator account, which must enable GuardDuty prior to being added as a member. If you are adding accounts by invitation use this action after GuardDuty has been enabled in potential member accounts and before using  Invite Members .

    Args:
        detector_id(str): The unique ID of the detector of the GuardDuty account that you want to associate member accounts with.
        account_details(List): A list of account ID and email address pairs of the accounts that you want to associate with the GuardDuty administrator account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.member.init.create_multiple(
                ctx, detector_id=value, account_details=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.member.init.create_multiple detector_id=value, account_details=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="create_members",
        op_kwargs={"DetectorId": detector_id, "AccountDetails": account_details},
    )


async def delete_multiple(hub, ctx, detector_id: str, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes GuardDuty member accounts (to the current GuardDuty administrator account) specified by the account IDs.

    Args:
        detector_id(str): The unique ID of the detector of the GuardDuty account whose members you want to delete.
        account_ids(List): A list of account IDs of the GuardDuty member accounts that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.member.init.delete_multiple(
                ctx, detector_id=value, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.member.init.delete_multiple detector_id=value, account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="delete_members",
        op_kwargs={"DetectorId": detector_id, "AccountIds": account_ids},
    )


async def disassociate(hub, ctx, detector_id: str, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates GuardDuty member accounts (to the current GuardDuty administrator account) specified by the account IDs.

    Args:
        detector_id(str): The unique ID of the detector of the GuardDuty account whose members you want to disassociate from the administrator account.
        account_ids(List): A list of account IDs of the GuardDuty member accounts that you want to disassociate from the administrator account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.member.init.disassociate(
                ctx, detector_id=value, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.member.init.disassociate detector_id=value, account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="disassociate_members",
        op_kwargs={"DetectorId": detector_id, "AccountIds": account_ids},
    )


async def get_all(hub, ctx, detector_id: str, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves GuardDuty member accounts (of the current GuardDuty administrator account) specified by the account IDs.

    Args:
        detector_id(str): The unique ID of the detector of the GuardDuty account whose members you want to retrieve.
        account_ids(List): A list of account IDs of the GuardDuty member accounts that you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.member.init.get_all(
                ctx, detector_id=value, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.member.init.get_all detector_id=value, account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="get_members",
        op_kwargs={"DetectorId": detector_id, "AccountIds": account_ids},
    )


async def invite(
    hub,
    ctx,
    detector_id: str,
    account_ids: List,
    disable_email_notification: bool = None,
    message: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Invites other AWS accounts (created as members of the current AWS account by CreateMembers) to enable GuardDuty, and allow the current AWS account to view and manage these accounts' findings on their behalf as the GuardDuty administrator account.

    Args:
        detector_id(str): The unique ID of the detector of the GuardDuty account that you want to invite members with.
        account_ids(List): A list of account IDs of the accounts that you want to invite to GuardDuty as members.
        disable_email_notification(bool, optional): A Boolean value that specifies whether you want to disable email notification to the accounts that you are inviting to GuardDuty as members. Defaults to None.
        message(str, optional): The invitation message that you want to send to the accounts that you're inviting to GuardDuty as members. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.member.init.invite(
                ctx, detector_id=value, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.member.init.invite detector_id=value, account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="invite_members",
        op_kwargs={
            "DetectorId": detector_id,
            "AccountIds": account_ids,
            "DisableEmailNotification": disable_email_notification,
            "Message": message,
        },
    )


async def list_all(
    hub,
    ctx,
    detector_id: str,
    max_results: int = None,
    next_token: str = None,
    only_associated: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists details about all member accounts for the current GuardDuty administrator account.

    Args:
        detector_id(str): The unique ID of the detector the member is associated with.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50. The maximum value is 50. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.
        only_associated(str, optional): Specifies whether to only return associated members or to return all members (including members who haven't been invited yet or have been disassociated). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.member.init.list_all(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.member.init.list_all detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="list_members",
        op_kwargs={
            "DetectorId": detector_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "OnlyAssociated": only_associated,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx, connector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified connector from AWS SMS. After you disassociate a connector, it is no longer available to support replication jobs.

    Args:
        connector_id(str): The ID of the connector.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.connector.disassociate(ctx, connector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.connector.disassociate connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="disassociate_connector",
        op_kwargs={"connectorId": connector_id},
    )


async def get_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the connectors registered with the AWS SMS.

    Args:
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. The default value is 50. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.connector.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.connector.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="get_connectors",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def remove(hub, ctx, instance_profile_name: str, role_name: str) -> None:
    r"""
    **Autogenerated function**

    Removes the specified IAM role from the specified EC2 instance profile.  Make sure that you do not have any Amazon EC2 instances running with the role you are about to remove from the instance profile. Removing a role from an instance profile that is associated with a running instance might break any applications running on the instance.   For more information about IAM roles, see Working with roles. For more information about instance profiles, see About instance profiles.

    Args:
        instance_profile_name(str): The name of the instance profile to update. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        role_name(str): The name of the role to remove. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.from_instance_profile.remove(
                ctx, instance_profile_name=value, role_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.from_instance_profile.remove instance_profile_name=value, role_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="remove_role_from_instance_profile",
        op_kwargs={"InstanceProfileName": instance_profile_name, "RoleName": role_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def build(hub, ctx, bot_id: str, bot_version: str, locale_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Builds a bot, its intents, and its slot types into a specific locale. A bot can be built into multiple locales. At runtime the locale is used to choose a specific build of the bot.

    Args:
        bot_id(str): The identifier of the bot to build. The identifier is returned in the response from the operation.
        bot_version(str): The version of the bot to build. This can only be the draft version of the bot.
        locale_id(str): The identifier of the language and locale that the bot will be used in. The string must match one of the supported locales. All of the intents, slot types, and slots used in the bot must have the same locale. For more information, see Supported languages.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.locale.build(
                ctx, bot_id=value, bot_version=value, locale_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.locale.build bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="build_bot_locale",
        op_kwargs={"botId": bot_id, "botVersion": bot_version, "localeId": locale_id},
    )


async def create(
    hub,
    ctx,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    nlu_intent_confidence_threshold: float,
    description: str = None,
    voice_settings: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a locale in the bot. The locale contains the intents and slot types that the bot uses in conversations with users in the specified language and locale. You must add a locale to a bot before you can add intents and slot types to the bot.

    Args:
        bot_id(str): The identifier of the bot to create the locale for.
        bot_version(str): The version of the bot to create the locale for. This can only be the draft version of the bot.
        locale_id(str): The identifier of the language and locale that the bot will be used in. The string must match one of the supported locales. All of the intents, slot types, and slots used in the bot must have the same locale. For more information, see Supported languages.
        description(str, optional): A description of the bot locale. Use this to help identify the bot locale in lists. Defaults to None.
        nlu_intent_confidence_threshold(float): Determines the threshold where Amazon Lex will insert the AMAZON.FallbackIntent, AMAZON.KendraSearchIntent, or both when returning alternative intents. AMAZON.FallbackIntent and AMAZON.KendraSearchIntent are only inserted if they are configured for the bot. For example, suppose a bot is configured with the confidence threshold of 0.80 and the AMAZON.FallbackIntent. Amazon Lex returns three alternative intents with the following confidence scores: IntentA (0.70), IntentB (0.60), IntentC (0.50). The response from the PostText operation would be:   AMAZON.FallbackIntent   IntentA   IntentB   IntentC  .
        voice_settings(Dict, optional): The Amazon Polly voice ID that Amazon Lex uses for voice interaction with the user. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.locale.create(
                ctx,
                bot_id=value,
                bot_version=value,
                locale_id=value,
                nlu_intent_confidence_threshold=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.locale.create bot_id=value, bot_version=value, locale_id=value, nlu_intent_confidence_threshold=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="create_bot_locale",
        op_kwargs={
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
            "description": description,
            "nluIntentConfidenceThreshold": nlu_intent_confidence_threshold,
            "voiceSettings": voice_settings,
        },
    )


async def delete(hub, ctx, bot_id: str, bot_version: str, locale_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a locale from a bot. When you delete a locale, all intents, slots, and slot types defined for the locale are also deleted.

    Args:
        bot_id(str): The unique identifier of the bot that contains the locale.
        bot_version(str): The version of the bot that contains the locale. .
        locale_id(str): The identifier of the language and locale that will be deleted. The string must match one of the supported locales. For more information, see Supported languages.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.locale.delete(
                ctx, bot_id=value, bot_version=value, locale_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.locale.delete bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_bot_locale",
        op_kwargs={"botId": bot_id, "botVersion": bot_version, "localeId": locale_id},
    )


async def describe(hub, ctx, bot_id: str, bot_version: str, locale_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the settings that a bot has for a specific locale.

    Args:
        bot_id(str): The identifier of the bot associated with the locale.
        bot_version(str): The identifier of the version of the bot associated with the locale.
        locale_id(str): The unique identifier of the locale to describe. The string must match one of the supported locales. For more information, see Supported languages. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.locale.describe(
                ctx, bot_id=value, bot_version=value, locale_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.locale.describe bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="describe_bot_locale",
        op_kwargs={"botId": bot_id, "botVersion": bot_version, "localeId": locale_id},
    )


async def list_all(
    hub,
    ctx,
    bot_id: str,
    bot_version: str,
    sort_by: Dict = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of locales for the specified bot.

    Args:
        bot_id(str): The identifier of the bot to list locales for.
        bot_version(str): The version of the bot to list locales for.
        sort_by(Dict, optional): Specifies sorting parameters for the list of locales. You can sort by locale name in ascending or descending order. Defaults to None.
        filters(List, optional): Provides the specification for a filter used to limit the response to only those locales that match the filter specification. You can only specify one filter and one value to filter on. Defaults to None.
        max_results(int, optional): The maximum number of aliases to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned. Defaults to None.
        next_token(str, optional): If the response from the ListBotLocales operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token as the nextToken parameter to return the next page of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.locale.list_all(
                ctx, bot_id=value, bot_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.locale.list_all bot_id=value, bot_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="list_bot_locales",
        op_kwargs={
            "botId": bot_id,
            "botVersion": bot_version,
            "sortBy": sort_by,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    nlu_intent_confidence_threshold: float,
    description: str = None,
    voice_settings: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the settings that a bot has for a specific locale.

    Args:
        bot_id(str): The unique identifier of the bot that contains the locale.
        bot_version(str): The version of the bot that contains the locale to be updated. The version can only be the DRAFT version.
        locale_id(str): The identifier of the language and locale to update. The string must match one of the supported locales. For more information, see Supported languages.
        description(str, optional): The new description of the locale. Defaults to None.
        nlu_intent_confidence_threshold(float): The new confidence threshold where Amazon Lex inserts the AMAZON.FallbackIntent and AMAZON.KendraSearchIntent intents in the list of possible intents for an utterance.
        voice_settings(Dict, optional): The new Amazon Polly voice Amazon Lex should use for voice interaction with the user. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.locale.update(
                ctx,
                bot_id=value,
                bot_version=value,
                locale_id=value,
                nlu_intent_confidence_threshold=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.locale.update bot_id=value, bot_version=value, locale_id=value, nlu_intent_confidence_threshold=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="update_bot_locale",
        op_kwargs={
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
            "description": description,
            "nluIntentConfidenceThreshold": nlu_intent_confidence_threshold,
            "voiceSettings": voice_settings,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def restore(
    hub,
    ctx,
    cluster_identifier: str,
    snapshot_identifier: str,
    source_database_name: str,
    source_table_name: str,
    new_table_name: str,
    source_schema_name: str = None,
    target_database_name: str = None,
    target_schema_name: str = None,
    enable_case_sensitive_identifier: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new table from a table in an Amazon Redshift cluster snapshot. You must create the new table within the Amazon Redshift cluster that the snapshot was taken from. You cannot use RestoreTableFromClusterSnapshot to restore a table with the same name as an existing table in an Amazon Redshift cluster. That is, you cannot overwrite an existing table in a cluster with a restored table. If you want to replace your original table with a new, restored table, then rename or drop your original table before you call RestoreTableFromClusterSnapshot. When you have renamed your original table, then you can pass the original name of the table as the NewTableName parameter value in the call to RestoreTableFromClusterSnapshot. This way, you can replace the original table with the table created from the snapshot.

    Args:
        cluster_identifier(str): The identifier of the Amazon Redshift cluster to restore the table to.
        snapshot_identifier(str): The identifier of the snapshot to restore the table from. This snapshot must have been created from the Amazon Redshift cluster specified by the ClusterIdentifier parameter.
        source_database_name(str): The name of the source database that contains the table to restore from.
        source_schema_name(str, optional): The name of the source schema that contains the table to restore from. If you do not specify a SourceSchemaName value, the default is public. Defaults to None.
        source_table_name(str): The name of the source table to restore from.
        target_database_name(str, optional): The name of the database to restore the table to. Defaults to None.
        target_schema_name(str, optional): The name of the schema to restore the table to. Defaults to None.
        new_table_name(str): The name of the table to create as a result of the current request.
        enable_case_sensitive_identifier(bool, optional): Indicates whether name identifiers for database, schema, and table are case sensitive. If true, the names are case sensitive. If false (default), the names are not case sensitive. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.table.from_cluster_snapshot.restore(
                ctx,
                cluster_identifier=value,
                snapshot_identifier=value,
                source_database_name=value,
                source_table_name=value,
                new_table_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.table.from_cluster_snapshot.restore cluster_identifier=value, snapshot_identifier=value, source_database_name=value, source_table_name=value, new_table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="restore_table_from_cluster_snapshot",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "SnapshotIdentifier": snapshot_identifier,
            "SourceDatabaseName": source_database_name,
            "SourceSchemaName": source_schema_name,
            "SourceTableName": source_table_name,
            "TargetDatabaseName": target_database_name,
            "TargetSchemaName": target_schema_name,
            "NewTableName": new_table_name,
            "EnableCaseSensitiveIdentifier": enable_case_sensitive_identifier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, instance_id: str, key: str) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Associates a security key to the instance.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        key(str): A valid security key in PEM format.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.security.key.associate(
                ctx, instance_id=value, key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.security.key.associate instance_id=value, key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="associate_security_key",
        op_kwargs={"InstanceId": instance_id, "Key": key},
    )


async def disassociate(hub, ctx, instance_id: str, association_id: str) -> None:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Deletes the specified security key.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        association_id(str): The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.security.key.disassociate(
                ctx, instance_id=value, association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.security.key.disassociate instance_id=value, association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="disassociate_security_key",
        op_kwargs={"InstanceId": instance_id, "AssociationId": association_id},
    )


async def list_all(
    hub, ctx, instance_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Returns a paginated list of all security keys associated with the instance.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.security.key.list_all(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.security.key.list_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_security_keys",
        op_kwargs={
            "InstanceId": instance_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, platform_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information on a specific signing platform.

    Args:
        platform_id(str): The ID of the target signing platform.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signing.platform.get(ctx, platform_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signing.platform.get platform_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="get_signing_platform",
        op_kwargs={"platformId": platform_id},
    )


async def list_all(
    hub,
    ctx,
    category: str = None,
    partner: str = None,
    target: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all signing platforms available in code signing that match the request parameters. If additional jobs remain to be listed, code signing returns a nextToken value. Use this value in subsequent calls to ListSigningJobs to fetch the remaining values. You can continue calling ListSigningJobs with your maxResults parameter and with new values that code signing returns in the nextToken parameter until all of your signing jobs have been returned.

    Args:
        category(str, optional): The category type of a signing platform. Defaults to None.
        partner(str, optional): Any partner entities connected to a signing platform. Defaults to None.
        target(str, optional): The validation template that is used by the target signing platform. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned by this operation. Defaults to None.
        next_token(str, optional): Value for specifying the next set of paginated results to return. After you receive a response with truncated results, use this parameter in a subsequent request. Set it to the value of nextToken from the response that you just received. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signing.platform.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signing.platform.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="list_signing_platforms",
        op_kwargs={
            "category": category,
            "partner": partner,
            "target": target,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub,
    ctx,
    instance_id: str,
    capacity_reservation_specification: Dict,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the Capacity Reservation settings for a stopped instance. Use this action to configure an instance to target a specific Capacity Reservation, run in any open Capacity Reservation with matching attributes, or run On-Demand Instance capacity.

    Args:
        instance_id(str): The ID of the instance to be modified.
        capacity_reservation_specification(Dict): Information about the Capacity Reservation targeting option.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.capacity_reservation_attribute.modify(
                ctx, instance_id=value, capacity_reservation_specification=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.capacity_reservation_attribute.modify instance_id=value, capacity_reservation_specification=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_instance_capacity_reservation_attributes",
        op_kwargs={
            "InstanceId": instance_id,
            "CapacityReservationSpecification": capacity_reservation_specification,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, accelerator_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describe the attributes of a custom routing accelerator.

    Args:
        accelerator_arn(str): The Amazon Resource Name (ARN) of the custom routing accelerator to describe the attributes for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.accelerator.attribute.describe_all(
                ctx, accelerator_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.accelerator.attribute.describe_all accelerator_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="describe_custom_routing_accelerator_attributes",
        op_kwargs={"AcceleratorArn": accelerator_arn},
    )


async def update_multiple(
    hub,
    ctx,
    accelerator_arn: str,
    flow_logs_enabled: bool = None,
    flow_logs_s3_bucket: str = None,
    flow_logs_s3_prefix: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update the attributes for a custom routing accelerator.

    Args:
        accelerator_arn(str): The Amazon Resource Name (ARN) of the custom routing accelerator to update attributes for.
        flow_logs_enabled(bool, optional): Update whether flow logs are enabled. The default value is false. If the value is true, FlowLogsS3Bucket and FlowLogsS3Prefix must be specified. For more information, see Flow Logs in the AWS Global Accelerator Developer Guide. Defaults to None.
        flow_logs_s3_bucket(str, optional): The name of the Amazon S3 bucket for the flow logs. Attribute is required if FlowLogsEnabled is true. The bucket must exist and have a bucket policy that grants AWS Global Accelerator permission to write to the bucket. Defaults to None.
        flow_logs_s3_prefix(str, optional): Update the prefix for the location in the Amazon S3 bucket for the flow logs. Attribute is required if FlowLogsEnabled is true.  If you don’t specify a prefix, the flow logs are stored in the root of the bucket. If you specify slash (/) for the S3 bucket prefix, the log file bucket folder structure will include a double slash (//), like the following: DOC-EXAMPLE-BUCKET//AWSLogs/aws_account_id. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.accelerator.attribute.update_multiple(
                ctx, accelerator_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.accelerator.attribute.update_multiple accelerator_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="update_custom_routing_accelerator_attributes",
        op_kwargs={
            "AcceleratorArn": accelerator_arn,
            "FlowLogsEnabled": flow_logs_enabled,
            "FlowLogsS3Bucket": flow_logs_s3_bucket,
            "FlowLogsS3Prefix": flow_logs_s3_prefix,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    application_id: str,
    semantic_version: str,
    source_code_archive_url: str = None,
    source_code_url: str = None,
    template_body: str = None,
    template_url: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an application version.

    Args:
        application_id(str): The Amazon Resource Name (ARN) of the application.
        semantic_version(str): The semantic version of the new version.
        source_code_archive_url(str, optional): A link to the S3 object that contains the ZIP archive of the source code for this version of your application.Maximum size 50 MB. Defaults to None.
        source_code_url(str, optional): A link to a public repository for the source code of your application, for example the URL of a specific GitHub commit. Defaults to None.
        template_body(str, optional): The raw packaged AWS SAM template of your application. Defaults to None.
        template_url(str, optional): A link to the packaged AWS SAM template of your application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.application.version.create(
                ctx, application_id=value, semantic_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.application.version.create application_id=value, semantic_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="create_application_version",
        op_kwargs={
            "ApplicationId": application_id,
            "SemanticVersion": semantic_version,
            "SourceCodeArchiveUrl": source_code_archive_url,
            "SourceCodeUrl": source_code_url,
            "TemplateBody": template_body,
            "TemplateUrl": template_url,
        },
    )


async def list_all(
    hub, ctx, application_id: str, max_items: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists versions for the specified application.

    Args:
        application_id(str): The Amazon Resource Name (ARN) of the application.
        max_items(int, optional): The total number of items to return. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.application.version.list_all(
                ctx, application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.application.version.list_all application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="list_application_versions",
        op_kwargs={
            "ApplicationId": application_id,
            "MaxItems": max_items,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, game_session_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the location of stored game session logs for a specified game session. When a game session is terminated, GameLift automatically stores the logs in Amazon S3 and retains them for 14 days. Use this URL to download the logs.  See the AWS Service Limits page for maximum log file sizes. Log files that exceed this limit are not saved.   Related actions   CreateGameSession | DescribeGameSessions | DescribeGameSessionDetails | SearchGameSessions | UpdateGameSession | GetGameSessionLogUrl | StartGameSessionPlacement | DescribeGameSessionPlacement | StopGameSessionPlacement | All APIs by task

    Args:
        game_session_id(str): A unique identifier for the game session to get logs for. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.log_url.get(ctx, game_session_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.log_url.get game_session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="get_game_session_log_url",
        op_kwargs={"GameSessionId": game_session_id},
    )
